@@ -20,67 +20,33 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-sns-lambda`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.snslambda`|
 
-## Overview
-
 This AWS Solutions Construct implements an Amazon SNS connected to an AWS Lambda function.
 
-Here is a minimal deployable pattern definition:
-
-Typescript
+Here is a minimal deployable pattern definition in Typescript:
 
 ```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
 import { SnsToLambda, SnsToLambdaProps } from "@aws-solutions-constructs/aws-sns-lambda";
-import * as lambda from 'aws-cdk-lib/aws-lambda';
 
 new SnsToLambda(this, 'test-sns-lambda', {
-  lambdaFunctionProps: {
-    runtime: lambda.Runtime.NODEJS_14_X,
-    handler: 'index.handler',
-    code: lambda.Code.fromAsset(`lambda`)
-  }
+    lambdaFunctionProps: {
+        runtime: lambda.Runtime.NODEJS_14_X,
+        handler: 'index.handler',
+        code: lambda.Code.fromAsset(`${__dirname}/lambda`)
+    }
 });
 ```
 
-Python
+## Initializer
 
-```python
-from aws_solutions_constructs.aws_sns_lambda import SnsToLambda
-from aws_cdk import (
-    aws_lambda as _lambda,
-    Stack
-)
-from constructs import Construct
-
-SnsToLambda(self, 'test_sns_lambda',
-            lambda_function_props=_lambda.FunctionProps(
-                code=_lambda.Code.from_asset('lambda'),
-                runtime=_lambda.Runtime.PYTHON_3_9,
-                handler='index.handler'
-            )
-            )
+```text
+new SnsToLambda(scope: Construct, id: string, props: SnsToLambdaProps);
 ```
 
-Java
+*Parameters*
 
-```java
-import software.constructs.Construct;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awscdk.services.lambda.*;
-import software.amazon.awscdk.services.lambda.Runtime;
-import software.amazon.awsconstructs.services.snslambda.*;
-
-new SnsToLambda(this, "test-lambda-sqs-stack", new SnsToLambdaProps.Builder()
-        .lambdaFunctionProps(new FunctionProps.Builder()
-                .runtime(Runtime.NODEJS_14_X)
-                .code(Code.fromAsset("lambda"))
-                .handler("index.handler")
-                .build())
-        .build());
-```
+* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
+* id `string`
+* props [`SnsToLambdaProps`](#pattern-construct-props)
 
 ## Pattern Construct Props
 
@@ -124,7 +90,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -136,17 +102,15 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_lambda
 import aws_cdk.aws_sns
-import aws_cdk.core
+import constructs
 
 
 class SnsToLambda(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-sns-lambda.SnsToLambda",
 ):
@@ -156,13 +120,13 @@ class SnsToLambda(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-        topic_props: typing.Optional[typing.Union[aws_cdk.aws_sns.TopicProps, typing.Dict[str, typing.Any]]] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        topic_props: typing.Optional[aws_cdk.aws_sns.TopicProps] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -176,20 +140,6 @@ class SnsToLambda(
         :since: 0.8.0
         :summary: Constructs a new instance of the LambdaToSns class.
         '''
-        if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-                existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
-                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-                topic_props: typing.Optional[typing.Union[aws_cdk.aws_sns.TopicProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = SnsToLambdaProps(
             existing_lambda_obj=existing_lambda_obj,
             existing_topic_obj=existing_topic_obj,
@@ -199,12 +149,12 @@ class SnsToLambda(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="snsTopic")
     def sns_topic(self) -> aws_cdk.aws_sns.Topic:
         return typing.cast(aws_cdk.aws_sns.Topic, jsii.get(self, "snsTopic"))
@@ -226,8 +176,8 @@ class SnsToLambdaProps:
         *,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-        topic_props: typing.Optional[typing.Union[aws_cdk.aws_sns.TopicProps, typing.Dict[str, typing.Any]]] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        topic_props: typing.Optional[aws_cdk.aws_sns.TopicProps] = None,
     ) -> None:
         '''
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
@@ -241,20 +191,6 @@ class SnsToLambdaProps:
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(topic_props, dict):
             topic_props = aws_cdk.aws_sns.TopicProps(**topic_props)
-        if __debug__:
-            def stub(
-                *,
-                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-                existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
-                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-                topic_props: typing.Optional[typing.Union[aws_cdk.aws_sns.TopicProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
-            check_type(argname="argument existing_topic_obj", value=existing_topic_obj, expected_type=type_hints["existing_topic_obj"])
-            check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
-            check_type(argname="argument topic_props", value=topic_props, expected_type=type_hints["topic_props"])
         self._values: typing.Dict[str, typing.Any] = {}
         if existing_lambda_obj is not None:
             self._values["existing_lambda_obj"] = existing_lambda_obj
